wsgo

package module
v1.0.21 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

README

Minimal P2P server in Go

Go Reference

wsgo is a lightweight Go library that provides a simple interface for building p2p-based applications. It includes reusable packages for client and server functionality and runnable command-line examples.

Features

  • Supports TCP and Websocket protocols
  • Docker support for servers

ToDo

  • Add support for QUIC and WebRTC

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type P2PServer

type P2PServer = p2p.P2PServer

type WsClient

type WsClient = client.WsClient

type WsServer

type WsServer = server.WsServer

Directories

Path Synopsis
cmd
client command
p2p command
server command
internal

Jump to