package
Version:
v1.0.21
Opens a new window with list of versions in this module.
Published: Feb 11, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Message struct {
Sender string `json:"sender"`
Receiver string `json:"receiver"`
Content []byte `json:"content"`
}
Message represents a message exchanged between peers
NewMessage creates a new message with validation
Validate checks if the message is valid
const (
TCP Type = "tcp"
WebSocket Type = "websocket"
QUIC Type = "quic"
WebRTC Type = "webrtc"
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.